@@ -39,7 +39,7 @@ def _parse_field_values_from_string(model: Model) -> None:
     """
     Convert the model fields' value to match the field type if appropriate.
 
-    This is mostly to deal field string values that will get saved as a date-related field.
+    This is mostly to deal with field string values that will get saved as a date-related field.
     """
 
     for field in model._meta.fields:
@@ -73,6 +73,20 @@ def _get_model_dict(model: Model) -> dict:
     model_json = model_json.get("fields")
     model_json["pk"] = model_pk
 
+    for field in model._meta.get_fields():
+        if field.is_relation and field.many_to_many:
+            related_name = field.related_name or f"{field.name}_set"
+            pks = []
+
+            try:
+                related_descriptor = getattr(model, related_name)
+                pks = list(related_descriptor.values_list("pk", flat=True))
+            except ValueError:
+                # ValueError is throuwn when the model doesn't have an id already set
+                pass
+
+            model_json[related_name] = pks
+
     return model_json
 
 
@@ -101,7 +115,12 @@ def _json_serializer(obj):
             queryset_json = []
 
             for model in obj:
-                model_json = _get_model_dict(model)
+                if obj.query.values_select and isinstance(model, dict):
+                    # If the queryset was created with values it's already a dictionary
+                    model_json = model
+                else:
+                    model_json = _get_model_dict(model)
+
                 queryset_json.append(model_json)
 
             return queryset_json
@@ -192,3 +211,21 @@ def loads(str: str) -> dict:
         return orjson.loads(str)
     except orjson.JSONDecodeError as e:
         raise JSONDecodeError from e
+
+
+def model_value(model: Model, *fields: str):
+    """
+    Serializes a model into a dictionary with the fields as specified in the `fields` argument.
+    """
+
+    model_data = {}
+    model_dict = _get_model_dict(model)
+
+    if not fields:
+        return model_dict
+
+    for field in fields:
+        if field in model_dict:
+            model_data[field] = model_dict[field]
+
+    return model_data
